@@ -137,11 +137,13 @@ def apply_on_groupby_parallel(df_grouped: DataFrameGroupBy, func: Callable, n_co
     res = pool.map(partial(_groupby_serial_func, func=func, pbar=pbar), split_data)
 
     # Concatenate the result to preserve the original result of a regular groupby pandas code.
-    concat_res = np.concatenate(res)
+    # concat_res = np.concatenate(res)
+    concat_res = []
+    for i in range(len(res)):
+        concat_res.extend(res[i])
 
-    if len(concat_res[0].shape) > 0:
-        columns = res[0][0].index
-        res = pd.DataFrame(concat_res, columns=columns)
+    if isinstance(concat_res[0], (pd.DataFrame, pd.Series)):
+        res = pd.DataFrame(concat_res)
     else:
         res = pd.Series(concat_res)
 
